==> ejc-salary-api-3.0.0-20240920.090714-5-sources.jar: com/ejianc/business/salary/vo/RosterAttendanceVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-出勤
 * 
 * @author generator
 * 
 */
public class RosterAttendanceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private Integer month; // 月份
    private Integer shouldDay; // 应出勤天数
    private Integer actualDay; // 实际出勤天数
    private Long syncDay; // 同步日期
    private String hrId; // 人力主键
    private Integer hrState; // 人力状态（1：正常，2：删除）
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public Integer getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(Integer shouldDay) {
        this.shouldDay = shouldDay;
    }
    public Integer getActualDay() {
        return actualDay;
    }

    public void setActualDay(Integer actualDay) {
        this.actualDay = actualDay;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-api-3.0.0-20250528.024757-134-sources.jar: com/ejianc/business/salary/vo/RosterAttendanceVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-出勤
 * 
 * @author generator
 * 
 */
public class RosterAttendanceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private Integer month; // 月份
    private BigDecimal shouldDay; // 应出勤天数
    private BigDecimal actualDay; // 实际出勤天数
    private Long syncDay; // 同步日期
    private String hrId; // 人力主键
    private Integer hrState; // 人力状态（1：正常，2：删除）
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public BigDecimal getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(BigDecimal shouldDay) {
        this.shouldDay = shouldDay;
    }
    public BigDecimal getActualDay() {
        return actualDay;
    }

    public void setActualDay(BigDecimal actualDay) {
        this.actualDay = actualDay;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
